==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/pt/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => 'Registo de <strong>Conta</strong>',
    '<strong>Change</strong> Password' => '<strong>Alterar</strong> palavra-passe',
    '<strong>Change</strong> your password' => '<strong>Altera</strong> a tua palavra-passe',
    '<strong>Join</strong> the network' => '<strong>Junta-te</strong> a nós!',
    '<strong>Password</strong> changed!' => '<strong>Palavra-passe</strong> alterada',
    '<strong>Password</strong> recovery' => '<strong>Palavra-passe</strong> recuperada',
    '<strong>Password</strong> recovery!' => '<strong>Recuperação</strong> de palavra-passe!',
    '<strong>Please</strong> sign in' => '<strong>Clica</strong> em Entrar',
    '<strong>Registration</strong> successful!' => '<strong>Registo</strong> efectuado com sucesso!',
    '<strong>Sign</strong> up' => '<strong>Regista-te</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>A tua conta</strong> foi criada com sucesso!',
    'Account' => 'Conta',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Depois da tua conta ser ativada pela administração, serás notificado por email.',
    'Back' => 'Voltar',
    'Change password' => 'Alterar palavra-passe',
    'Confirm' => 'Confirmar',
    'Create Account' => 'Criar Conta',
    'Create account' => 'Criar conta',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Não tens uma conta? Para te juntares, introduz o teu endereço de e-mail.',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Devido a razões de segurança, necessitas de alterar a tua palavra-passe para poderes aceder à plataforma.',
    'Enter security code above' => 'Escreve o código de segurança acima',
    'Forgot your password?' => 'Esqueceste-te da tua palavra-passe?',
    'Go to login page' => 'Ir para a página de entrada',
    'Group' => 'Grupo',
    'Hello {displayName}' => 'Olá {displayName}',
    'Hello {displayName},' => 'Olá {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Se não usares este link nas próximas 24 horas, este auto-destruir-se-á.',
    'If you\'re already a member, please login with your username/email and password.' => 'Se já és um membro, por favor entra com o teu nome de utilizador ou e-mail e palavra-passe',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Basta escrever o teu e-mail. Enviar-te-emos as instruções para recuperação!',
    'Log out' => 'Sair',
    'Login' => 'Entrar',
    'New user needs approval' => 'Novo utilizador necessita de aprovação',
    'Password' => 'palavra-passe',
    'Password recovery' => 'Recuperação de palavra-passe',
    'Password reset' => 'Redefinição de palavra-passe',
    'Please check your email and follow the instructions!' => 'Por favor vai ao teu email e segue as instruções!',
    'Please click on the link below to view request:' => 'Por favor clica no link abaixo para ver o pedido:',
    'Please enter the letters from the image.' => 'Por favor escreve as letras da imagem.',
    'Please login with your username/email and password.' => 'Por favor entra com o teu nome de utilizador ou e-mail e palavra-passe.',
    'Please use the following link within the next day to reset your password.' => 'Por favor usa o link seguinte durante as próximas 24 horas para redefinir a tua palavra-passe.',
    'Please wait' => 'Por favor aguarda',
    'Register' => 'Regista-te',
    'Registration successful' => 'Registado com sucesso',
    'Remember me' => 'Lembrar-se de mim e manter-me ligado',
    'Reset Password' => 'Redefinir Palavra-passe',
    'Reset password' => 'Redefinir palavra-passe',
    'Sign in' => 'Entrar',
    'To log in with your new account, click the button below.' => 'Para entrares com a tua nova conta, clica no botão abaixo.',
    'User or Password incorrect.' => 'Utilizador ou Palavra-passe incorreta.',
    'Username or Email' => 'nome de utilizador ou e-mail',
    'Your email' => 'O teu e-mail',
    'Your password' => 'A tua palavra-passe',
    'Your password has been successfully changed!' => 'A tua palavra-passe foi alterada com sucesso!',
    'Your password is incorrect!' => 'A tua palavra-passe está incorreta!',
    'a new user {displayName} needs approval.' => 'um novo utilizador {displayName} necessita de aprovação.',
    'back to home' => 'voltar à página inicial',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/pt/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => 'Registo de <strong>Conta</strong>',
    '<strong>Change</strong> Password' => '<strong>Alterar</strong> palavra-passe',
    '<strong>Change</strong> your password' => '<strong>Altera</strong> a tua palavra-passe',
    '<strong>Join</strong> the network' => '<strong>Junta-te</strong> a nós!',
    '<strong>Password</strong> changed!' => '<strong>Palavra-passe</strong> alterada',
    '<strong>Password</strong> recovery' => '<strong>Palavra-passe</strong> recuperada',
    '<strong>Password</strong> recovery!' => '<strong>Recuperação</strong> de palavra-passe!',
    '<strong>Please</strong> sign in' => '<strong>Clica</strong> em Entrar',
    '<strong>Registration</strong> successful!' => '<strong>Registo</strong> efectuado com sucesso!',
    '<strong>Sign</strong> up' => '<strong>Regista-te</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>A tua conta</strong> foi criada com sucesso!',
    'Account' => 'Conta',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Depois da tua conta ser ativada pela administração, serás notificado por email.',
    'Back' => 'Voltar',
    'Change password' => 'Alterar palavra-passe',
    'Confirm' => 'Confirmar',
    'Create Account' => 'Criar Conta',
    'Create account' => 'Criar conta',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Não tens uma conta? Para te juntares, introduz o teu endereço de e-mail.',
    'Due to security reasons you are required to change your password in order to access the platform.' => 'Devido a razões de segurança, necessitas de alterar a tua palavra-passe para poderes aceder à plataforma.',
    'Forgot your password?' => 'Esqueceste-te da tua palavra-passe?',
    'Go to login page' => 'Ir para a página de entrada',
    'Group' => 'Grupo',
    'Hello {displayName}' => 'Olá {displayName}',
    'Hello {displayName},' => 'Olá {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Se não usares este link nas próximas 24 horas, este auto-destruir-se-á.',
    'If you\'re already a member, please login with your username/email and password.' => 'Se já és um membro, por favor entra com o teu nome de utilizador ou e-mail e palavra-passe',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Basta escrever o teu e-mail. Enviar-te-emos as instruções para recuperação!',
    'Log out' => 'Sair',
    'Login' => 'Entrar',
    'New user needs approval' => 'Novo utilizador necessita de aprovação',
    'Password' => 'palavra-passe',
    'Password recovery' => 'Recuperação de palavra-passe',
    'Password reset' => 'Redefinição de palavra-passe',
    'Please click on the link below to view request:' => 'Por favor clica no link abaixo para ver o pedido:',
    'Please login with your username/email and password.' => 'Por favor entra com o teu nome de utilizador ou e-mail e palavra-passe.',
    'Please use the following link within the next day to reset your password.' => 'Por favor usa o link seguinte durante as próximas 24 horas para redefinir a tua palavra-passe.',
    'Please wait' => 'Por favor aguarda',
    'Register' => 'Regista-te',
    'Remember me' => 'Lembrar-se de mim e manter-me ligado',
    'Reset Password' => 'Redefinir Palavra-passe',
    'Reset password' => 'Redefinir palavra-passe',
    'Sign in' => 'Entrar',
    'To log in with your new account, click the button below.' => 'Para entrares com a tua nova conta, clica no botão abaixo.',
    'User or Password incorrect.' => 'Utilizador ou Palavra-passe incorreta.',
    'Username or Email' => 'nome de utilizador ou e-mail',
    'Your email' => 'O teu e-mail',
    'Your password' => 'A tua palavra-passe',
    'Your password has been successfully changed!' => 'A tua palavra-passe foi alterada com sucesso!',
    'Your password is incorrect!' => 'A tua palavra-passe está incorreta!',
    'a new user {displayName} needs approval.' => 'um novo utilizador {displayName} necessita de aprovação.',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
];
